.. nodoctest

Diophantine Approximation
=========================

.. automodule:: slabbe.diophantine_approx
   :members:
   :undoc-members:
   :show-inheritance:
   
.. automodule:: slabbe.diophantine_approx_pyx
   :members:
   :undoc-members:
   :show-inheritance:
